List:Commits« Previous MessageNext Message »
From:Sven Sandberg Date:October 16 2008 2:40pm
Subject:bzr commit into mysql-6.0-rpl branch (sven:2711) Bug#39853
View as plain text  
#At file:///home/sven/bzr/b39853-lowercase_table3/6.0-rpl/

 2711 Sven Sandberg	2008-10-16 [merge]
      merged fix for BUG#39853 from 5.1-rpl to 6.0-rpl
modified:
  mysql-test/include/mtr_warnings.sql
  mysql-test/r/mysql_upgrade.result
  mysql-test/r/mysqlcheck.result
  mysql-test/suite/rpl/r/rpl_bug33931.result
  mysql-test/suite/rpl/r/rpl_idempotency.result
  mysql-test/suite/rpl/r/rpl_temporary.result
  mysql-test/suite/rpl/r/rpl_temporary_errors.result
  mysql-test/suite/rpl/t/disabled.def
  mysql-test/suite/rpl/t/rpl_bug33931.test
  mysql-test/suite/rpl/t/rpl_idempotency.test
  mysql-test/suite/rpl/t/rpl_temporary.test
  mysql-test/suite/rpl/t/rpl_temporary_errors.test
  mysql-test/t/lowercase_table3.test

=== modified file 'mysql-test/include/mtr_warnings.sql'
--- a/mysql-test/r/mysql_upgrade.result	2008-10-14 09:48:04 +0000
+++ b/mysql-test/r/mysql_upgrade.result	2008-10-16 14:39:34 +0000
@@ -1,7 +1,7 @@
 Run mysql_upgrade once
-mtr.global_supressions                             OK
+mtr.global_suppressions                            OK
 mtr.suspicious_patterns                            OK
-mtr.test_supressions                               OK
+mtr.test_suppressions                              OK
 mysql.backup_history
 Error    : You can't use locks with log tables.
 status   : OK
@@ -38,9 +38,9 @@ mysql.user                              
 Run it again - should say already completed
 This installation of MySQL is already upgraded to VERSION, use --force if you still need to run mysql_upgrade
 Force should run it regardless of wether it's been run before
-mtr.global_supressions                             OK
+mtr.global_suppressions                            OK
 mtr.suspicious_patterns                            OK
-mtr.test_supressions                               OK
+mtr.test_suppressions                              OK
 mysql.backup_history
 Error    : You can't use locks with log tables.
 status   : OK
@@ -77,9 +77,9 @@ mysql.user                              
 CREATE USER mysqltest1@'%' IDENTIFIED by 'sakila';
 GRANT ALL ON *.* TO mysqltest1@'%';
 Run mysql_upgrade with password protected account
-mtr.global_supressions                             OK
+mtr.global_suppressions                            OK
 mtr.suspicious_patterns                            OK
-mtr.test_supressions                               OK
+mtr.test_suppressions                              OK
 mysql.backup_history
 Error    : You can't use locks with log tables.
 status   : OK
@@ -118,9 +118,9 @@ Run mysql_upgrade with a non existing se
 mysqlcheck: Got error when trying to connect
 FATAL ERROR: Upgrade failed
 set GLOBAL sql_mode='STRICT_ALL_TABLES,ANSI_QUOTES,NO_ZERO_DATE';
-mtr.global_supressions                             OK
+mtr.global_suppressions                            OK
 mtr.suspicious_patterns                            OK
-mtr.test_supressions                               OK
+mtr.test_suppressions                              OK
 mysql.backup_history
 Error    : You can't use locks with log tables.
 status   : OK

=== modified file 'mysql-test/r/mysqlcheck.result'
--- a/mysql-test/r/mysqlcheck.result	2008-10-10 09:42:05 +0000
+++ b/mysql-test/r/mysqlcheck.result	2008-10-16 14:39:34 +0000
@@ -1,9 +1,9 @@
 DROP TABLE IF EXISTS t1, `t``1`, `t 1`;
 drop view if exists v1;
 drop database if exists client_test_db;
-mtr.global_supressions                             OK
+mtr.global_suppressions                            OK
 mtr.suspicious_patterns                            OK
-mtr.test_supressions                               OK
+mtr.test_suppressions                              OK
 mysql.backup_history
 note     : The storage engine for the table doesn't support optimize
 mysql.backup_progress

=== modified file 'mysql-test/suite/rpl/r/rpl_bug33931.result'
--- a/mysql-test/suite/rpl/r/rpl_bug33931.result	2008-07-17 19:11:37 +0000
+++ b/mysql-test/suite/rpl/r/rpl_bug33931.result	2008-10-16 14:39:34 +0000
@@ -1,6 +1,6 @@
 reset master;
 reset slave;
-call mtr.add_supression("Failed during slave.*thread initialization");
+call mtr.add_suppression("Failed during slave.*thread initialization");
 SET GLOBAL debug="d,simulate_io_slave_error_on_init,simulate_sql_slave_error_on_init";
 start slave;
 show slave status;

=== modified file 'mysql-test/suite/rpl/r/rpl_idempotency.result'
--- a/mysql-test/suite/rpl/r/rpl_idempotency.result	2008-04-08 14:51:26 +0000
+++ b/mysql-test/suite/rpl/r/rpl_idempotency.result	2008-10-13 18:33:08 +0000
@@ -4,8 +4,8 @@ reset master;
 reset slave;
 drop table if exists t1,t2,t3,t4,t5,t6,t7,t8,t9;
 start slave;
-call mtr.add_supression("Slave: Can\'t find record in \'t1\' Error_code: 1032");
-call mtr.add_supression("Slave: Cannot add or update a child row: a foreign key constraint fails .* Error_code: 1452");
+call mtr.add_suppression("Slave: Can\'t find record in \'t1\' Error_code: 1032");
+call mtr.add_suppression("Slave: Cannot add or update a child row: a foreign key constraint fails .* Error_code: 1452");
 CREATE TABLE t1 (a INT PRIMARY KEY);
 CREATE TABLE t2 (a INT);
 INSERT INTO t1 VALUES (-1),(-2),(-3);

=== modified file 'mysql-test/suite/rpl/r/rpl_temporary.result'
--- a/mysql-test/suite/rpl/r/rpl_temporary.result	2008-08-07 20:51:09 +0000
+++ b/mysql-test/suite/rpl/r/rpl_temporary.result	2008-10-16 14:39:34 +0000
@@ -4,7 +4,7 @@ reset master;
 reset slave;
 drop table if exists t1,t2,t3,t4,t5,t6,t7,t8,t9;
 start slave;
-call mtr.add_supression("Slave: Can\'t find record in \'user\' Error_code: 1032");
+call mtr.add_suppression("Slave: Can\'t find record in \'user\' Error_code: 1032");
 reset master;
 SET @save_select_limit=@@session.sql_select_limit;
 SET @@session.sql_select_limit=10, @@session.pseudo_thread_id=100;

=== modified file 'mysql-test/suite/rpl/r/rpl_temporary_errors.result'
--- a/mysql-test/suite/rpl/r/rpl_temporary_errors.result	2008-08-25 12:44:40 +0000
+++ b/mysql-test/suite/rpl/r/rpl_temporary_errors.result	2008-10-16 14:39:34 +0000
@@ -4,7 +4,7 @@ reset master;
 reset slave;
 drop table if exists t1,t2,t3,t4,t5,t6,t7,t8,t9;
 start slave;
-call mtr.add_supression("Deadlock found");
+call mtr.add_suppression("Deadlock found");
 **** On Master ****
 SET SESSION BINLOG_FORMAT=ROW;
 CREATE TABLE t1 (a INT PRIMARY KEY, b INT);

=== modified file 'mysql-test/suite/rpl/t/disabled.def'
--- a/mysql-test/suite/rpl/t/disabled.def	2008-10-03 07:37:28 +0000
+++ b/mysql-test/suite/rpl/t/disabled.def	2008-10-16 14:39:34 +0000
@@ -27,10 +27,10 @@ rpl_log_pos                : Bug#8693 Te
 rpl_redirect               : Failure is sporadic and and the test is superfluous (mats)
 rpl_innodb_bug28430        : Failure on Solaris Bug #36793
 rpl_heartbeat              : Bug#37714 2008-07-14 alik Disabled to make 6.0 greaner (the test fails too often)
-rpl_idempotency            : Bug#37767 2008-07-14 alik Disabled to make 6.0 greaner (the test fails too often)
+#rpl_idempotency            : Bug#37767 2008-07-14 alik Disabled to make 6.0 greaner (the test fails too often)
 
 rpl_flushlog_loop          : Bug#37733 2008-07-17 alik Disabled to make 6.0 greaner (the test fails too often)
-rpl_temporary_errors       : Bug#36968 2008-07-17 alik Disabled to make 6.0 greaner (the test fails too often)
-rpl_temporary              : BUG#38269 2008-07-21 Sven valgrind error in pushbuild
+#rpl_temporary_errors       : Bug#36968 2008-07-17 alik Disabled to make 6.0 greaner (the test fails too often)
+#rpl_temporary              : BUG#38269 2008-07-21 Sven valgrind error in pushbuild
 rpl_flushlog_loop          : BUG#37733 2008-07-23 Sven disabled in 5.1-bugteam. the bug has been fixed in 5.1-rpl: please re-enable when that gets pushed to main
 rpl_server_id2             : Bug#38540 rpl_server_id2 uses show slave status unnecessarily

=== modified file 'mysql-test/suite/rpl/t/rpl_bug33931.test'
--- a/mysql-test/suite/rpl/t/rpl_bug33931.test	2008-06-23 21:23:41 +0000
+++ b/mysql-test/suite/rpl/t/rpl_bug33931.test	2008-10-16 14:39:34 +0000
@@ -14,8 +14,8 @@ reset master;
 connection slave;
 reset slave;
 
-# Add supression for expected warnings in slaves error log
-call mtr.add_supression("Failed during slave.*thread initialization");
+# Add suppression for expected warnings in slaves error log
+call mtr.add_suppression("Failed during slave.*thread initialization");
 
 # Set debug flags on slave to force errors to occur
 SET GLOBAL debug="d,simulate_io_slave_error_on_init,simulate_sql_slave_error_on_init";

=== modified file 'mysql-test/suite/rpl/t/rpl_idempotency.test'
--- a/mysql-test/suite/rpl/t/rpl_idempotency.test	2008-07-10 16:09:39 +0000
+++ b/mysql-test/suite/rpl/t/rpl_idempotency.test	2008-10-13 18:33:08 +0000
@@ -7,9 +7,9 @@ source include/have_innodb.inc;
 connection slave;
 source include/have_innodb.inc;
 
-# Add supression for expected warning(s) in slaves error log
-call mtr.add_supression("Slave: Can\'t find record in \'t1\' Error_code: 1032");
-call mtr.add_supression("Slave: Cannot add or update a child row: a foreign key constraint fails .* Error_code: 1452");
+# Add suppression for expected warning(s) in slaves error log
+call mtr.add_suppression("Slave: Can\'t find record in \'t1\' Error_code: 1032");
+call mtr.add_suppression("Slave: Cannot add or update a child row: a foreign key constraint fails .* Error_code: 1452");
 
 connection master;
 CREATE TABLE t1 (a INT PRIMARY KEY);

=== modified file 'mysql-test/suite/rpl/t/rpl_temporary.test'
--- a/mysql-test/suite/rpl/t/rpl_temporary.test	2008-08-07 20:51:09 +0000
+++ b/mysql-test/suite/rpl/t/rpl_temporary.test	2008-10-16 14:39:34 +0000
@@ -17,8 +17,8 @@ source include/add_anonymous_users.inc;
 save_master_pos;
 connection slave;
 
-# Add supression for expected warning(s) in slaves error log
-call mtr.add_supression("Slave: Can\'t find record in \'user\' Error_code: 1032");
+# Add suppression for expected warning(s) in slaves error log
+call mtr.add_suppression("Slave: Can\'t find record in \'user\' Error_code: 1032");
 
 sync_with_master;
 reset master;

=== modified file 'mysql-test/suite/rpl/t/rpl_temporary_errors.test'
--- a/mysql-test/suite/rpl/t/rpl_temporary_errors.test	2008-08-25 12:44:40 +0000
+++ b/mysql-test/suite/rpl/t/rpl_temporary_errors.test	2008-10-16 14:39:34 +0000
@@ -1,6 +1,6 @@
 source include/master-slave.inc;
 
-call mtr.add_supression("Deadlock found");
+call mtr.add_suppression("Deadlock found");
 
 --echo **** On Master ****
 connection master;

=== modified file 'mysql-test/t/lowercase_table3.test'
--- a/mysql-test/t/lowercase_table3.test	2008-07-10 23:14:13 +0000
+++ b/mysql-test/t/lowercase_table3.test	2008-10-13 18:33:08 +0000
@@ -9,6 +9,8 @@
 --source include/have_case_insensitive_file_system.inc
 --source include/not_windows.inc
 
+call mtr.add_suppression("Cannot find or open table test/BUG29839 from");
+
 --disable_warnings
 DROP TABLE IF EXISTS t1,T1;
 --enable_warnings

Thread
bzr commit into mysql-6.0-rpl branch (sven:2711) Bug#39853Sven Sandberg16 Oct
--- a/mysql-test/include/mtr_warnings.sql	2008-09-07 11:04:07 +0000
+++ b/mysql-test/include/mtr_warnings.sql	2008-10-16 14:39:34 +0000
@@ -42,9 +42,9 @@ INSERT INTO suspicious_patterns VALUES
 
 --
 -- Create table where testcases can insert patterns to
--- be supressed
+-- be suppressed
 --
-CREATE TABLE test_supressions (
+CREATE TABLE test_suppressions (
   pattern VARCHAR(255)
 ) ENGINE=MyISAM||
 
@@ -52,11 +52,11 @@ CREATE TABLE test_supressions (
 --
 -- Declare a trigger that makes sure
 -- no invalid patterns can be inserted
--- into test_supressions
+-- into test_suppressions
 --
 /*!50002
 CREATE DEFINER=root@localhost TRIGGER ts_insert
-BEFORE INSERT ON test_supressions
+BEFORE INSERT ON test_suppressions
 FOR EACH ROW BEGIN
   DECLARE dummy INT;
   SELECT "" REGEXP NEW.pattern INTO dummy;
@@ -65,20 +65,20 @@ END
 
 
 --
--- Load table with patterns that will be supressed globally(always)
+-- Load table with patterns that will be suppressed globally(always)
 --
-CREATE TABLE global_supressions (
+CREATE TABLE global_suppressions (
   pattern VARCHAR(255)
 ) ENGINE=MyISAM||
 
 
 -- Declare a trigger that makes sure
 -- no invalid patterns can be inserted
--- into global_supressions
+-- into global_suppressions
 --
 /*!50002
 CREATE DEFINER=root@localhost TRIGGER gs_insert
-BEFORE INSERT ON global_supressions
+BEFORE INSERT ON global_suppressions
 FOR EACH ROW BEGIN
   DECLARE dummy INT;
   SELECT "" REGEXP NEW.pattern INTO dummy;
@@ -88,9 +88,9 @@ END
 
 
 --
--- Insert patterns that should always be supressed
+-- Insert patterns that should always be suppressed
 --
-INSERT INTO global_supressions VALUES
+INSERT INTO global_suppressions VALUES
  ("'SELECT UNIX_TIMESTAMP\\(\\)' failed on master"),
  ("Aborted connection"),
  ("Client requested master to start replication from impossible position"),
@@ -256,28 +256,28 @@ BEGIN
   DELETE FROM error_log WHERE row < @max_row;
 
   CREATE TEMPORARY TABLE suspect_lines ENGINE=MyISAM AS
-   SELECT DISTINCT el.line, 0 as "supressed"
+   SELECT DISTINCT el.line, 0 as "suppressed"
      FROM error_log el, suspicious_patterns ep
        WHERE el.line REGEXP ep.pattern;
 
-  -- Mark lines that are supressed by global supressions
-  UPDATE suspect_lines sl, global_supressions gs
-    SET supressed=1
+  -- Mark lines that are suppressed by global suppressions
+  UPDATE suspect_lines sl, global_suppressions gs
+    SET suppressed=1
       WHERE sl.line REGEXP gs.pattern;
 
-  -- Mark lines that are supressed by test specific supressions
-  UPDATE suspect_lines sl, test_supressions ts
-    SET supressed=2
+  -- Mark lines that are suppressed by test specific suppressions
+  UPDATE suspect_lines sl, test_suppressions ts
+    SET suppressed=2
       WHERE sl.line REGEXP ts.pattern;
 
   SELECT COUNT(*) INTO @num_warnings FROM suspect_lines
-    WHERE supressed=0;
+    WHERE suppressed=0;
 
   IF @num_warnings > 0 THEN
     SELECT @log_error;
     SELECT line as log_error
-        FROM suspect_lines WHERE supressed=0;
-    --SELECT * FROM test_supressions;
+        FROM suspect_lines WHERE suppressed=0;
+    --SELECT * FROM test_suppressions;
     -- Return 2 -> check failed
     SELECT 2 INTO result;
   ELSE
@@ -286,19 +286,19 @@ BEGIN
   END IF;
 
   -- Cleanup for next test
-  TRUNCATE test_supressions;
+  TRUNCATE test_suppressions;
 
 END||
 
 --
 -- Declare a procedure testcases can use to insert test
--- specific supressions
+-- specific suppressions
 --
 /*!50001
 CREATE DEFINER=root@localhost
-PROCEDURE add_supression(pattern VARCHAR(255))
+PROCEDURE add_suppression(pattern VARCHAR(255))
 BEGIN
-  INSERT INTO test_supressions (pattern) VALUES (pattern);
+  INSERT INTO test_suppressions (pattern) VALUES (pattern);
 END
 */||
 

=== modified file 'mysql-test/r/mysql_upgrade.result'